<template>
  <el-dialog
    title="选择采购订单"
    :visible.sync="visible"
    :append-to-body="true"
    :modal-append-to-body="false"
    :close-on-click-modal="false"
    width="70%"
    :show-close="true"
    :before-close="handleClose"
    top="5vh"
    style="min-height: 700px"
  >
    <el-form :inline="true">
      <el-row :gutter="10">
        <el-col :span="24">
          <el-form-item label="订单号">
            <el-input
              v-model="querys[0].value"
              size="small"
              clearable
              placeholder="请输入订单号"
            />
          </el-form-item>
          <el-form-item label="订单标题">
            <el-input
              v-model="querys[1].value"
              size="small"
              clearable
              placeholder="请输入订单标题"
            />
          </el-form-item>
          <el-form-item label="采购人">
            <el-input
              v-model="querys[2].value"
              size="small"
              clearable
              placeholder="请输入采购人"
            />
          </el-form-item>
          <el-form-item>
            <el-button
              type="primary"
              size="small"
              icon="el-icon-search"
              @click="loadOrder"
              >搜索</el-button
            >
            <el-button size="small" icon="el-icon-refresh" @click="handleReset"
              >重置</el-button
            >
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <el-table
      :data="tableData"
      height="60vh"
      highlight-current-row
      @current-change="handleCurrentChange"
    >
      <el-table-column label="序号" type="index" width="60" />
      <el-table-column label="订单号" min-width="120" prop="code" />
      <el-table-column label="订单标题" min-width="120" prop="planTitle" />
      <el-table-column label="采购人" min-width="120" prop="planUserName" />
      <el-table-column label="采购部门" min-width="120" prop="orgName" />
    </el-table>
    <div slot="footer" class="dialog-footer">
      <el-button type="primary" @click="sure">确 定</el-button>
      <el-button @click="visible = false">取 消</el-button>
    </div>
  </el-dialog>
</template>
<script>
import materialIntoManage from '@/api/manager/material/materialIntoWarehouseManage.js'
export default {
  data() {
    return {
      visible: false,
      tableData: [],
      queryData: {
        pageBean: {
          page: 1,
          pageSize: 20,
          showTotal: true
        },
        querys: []
      },
      currentRow: null,
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'code_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'plan_title_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'plan_user_',
          relation: 'AND',
          value: ''
        }
      ]
    }
  },
  methods: {
    open() {
      this.visible = true
      this.loadOrder()
    },
    handleClose() {
      this.visible = false
    },
    handleCurrentChange(val) {
      this.currentRow = val
    },
    handleReset() {
      this.querys.forEach(item => {
        item.value = ''
      })
      this.loadOrder()
    },
    loadOrder() {
      this.queryData.querys = []
      this.querys.forEach(item => {
        if (item.value) {
          this.queryData.querys.push(item)
        }
      })
      materialIntoManage.getOrderData(this.queryData, res => {
        this.tableData = res.rows
      })
    },
    sure() {
      this.$emit('orderData', this.currentRow)
      this.visible = false
    }
  }
}
</script>
